@@ -1,5 +1,11 @@
+from .clip import Clip
 from .greater_equal_epsilon import GreaterEqualEpsilon
 from .greater_equal_epsilon_normalized import GreaterEqualEpsilonNormalized
 from .log_normalized import LogNormalized
 
-__all__ = ["GreaterEqualEpsilon", "GreaterEqualEpsilonNormalized", "LogNormalized"]
+__all__ = [
+    "Clip",
+    "GreaterEqualEpsilon",
+    "GreaterEqualEpsilonNormalized",
+    "LogNormalized",
+]
