@@ -1,9 +1,11 @@
+from libspn_keras.initializers.dirichlet import Dirichlet
 from libspn_keras.initializers.epsilon_inverse_fan_in import EpsilonInverseFanIn
 from libspn_keras.initializers.equidistant import Equidistant
 from libspn_keras.initializers.kmeans import KMeans
 from libspn_keras.initializers.poon_domingos import PoonDomingosMeanOfQuantileSplit
 
 __all__ = [
+    "Dirichlet",
     "EpsilonInverseFanIn",
     "Equidistant",
     "PoonDomingosMeanOfQuantileSplit",
